JweCompact

Struct JweCompact 

pub struct JweCompact { /* private fields */ }
A Compact JWE that is able to be deciphered or stringified for transmission

Implementations

Source

impl JweCompact

pub fn kid(&self) -> Option<&str>

Get the KID used to encipher this Jwe if present

pub fn get_jwk_pubkey_url(&self) -> Option<&Url>

Get the embedded Url for the Jwk that enciphered this Jwe.

You MUST ensure this url uses HTTPS and you MUST ensure that your client validates the CA’s used.

pub fn get_jwk_pubkey(&self) -> Option<&Jwk>

Get the embedded public key used to encipher this Jwe, if present.

pub fn get_alg_enc(&self) -> (JweAlg, JweEnc)

Return the CEK Algorithm and the inner encryption type.

pub fn header(&self) -> &JweProtectedHeader

View the content of the JWE header. At this point the content is UNVERIFIED and may NOT BE TRUSTED.